function h = arrowhead(x1,y1,x2,y2,ahlength,ahwidth,Color)
% function h = arrowhead(x1,y1,x2,y2,ahlength,ahwidth,Color)
%
% This function plots an arrowhead at location (x1,y1) pointing 
% in the direction from (x1,y1) to (x2,y2). The input ahlength 
% sets the length of the arrowhead from base to the tip.  The 
% input ahwidth is an optional input to set the width of the 
% arrowhead base (Default: ahwidth = ahlength/2). Finally, the last
% input can be used to set the color of the arrowhead.
%
% The output h is a handle to the arrowhead graphics object.

%% Set default ahwidth if not specified
if nargin==5
    ahwidth = [];
    Color = 'b';
elseif nargin==6
    Color = 'b';
end
if isempty(ahwidth)
    ahwidth = ahlength/2;    
end

%% Coordinates for arrowhead 
dx = (x2-x1);
dy = (y2-y1);
n = [dx dy]/norm([dx dy]);

ahx = [x1+ahlength*n(1); x1-(ahwidth/2)*n(2); x1+(ahwidth/2)*n(2)];
ahy = [y1+ahlength*n(2); y1+(ahwidth/2)*n(1); y1-(ahwidth/2)*n(1)];

h = patch(ahx,ahy,Color);
set(h,'EdgeColor','none')


    
